parser.PythonBackend
The reference pure-Python parsing backend.
Usage
parser.PythonBackend()Parses each file off the event loop via anyio worker threads, keeping at most prefetch files in flight at once.
Methods
| Name | Description |
|---|---|
| parse_batch() | See Backend.parse_batch(). |
parse_batch()
Usage
parse_batch(paths, *, prefetch, spec=None)